@@ -54,7 +54,7 @@ class VideoLog(object):
                 file_thumb = filename[:-4] + "_thumb.jpg"
                 img = image["input_image"]
                 if max(img.shape) > max(self._max_output_size):
-                    img, _ = img_utils.resize_image_scale(img, max(self._max_output_size))
+                    img, scale = img_utils.resize_image_scale(img, max(self._max_output_size))
 
                 cv2.imwrite(os.path.join(self._dest_path, filename), img)
                 file_stat_img = os.stat(os.path.join(self._dest_path, filename))
@@ -66,6 +66,13 @@ class VideoLog(object):
                     cv2.imwrite(os.path.join(self._dest_path, file_thumb), img)
                 file_stat_thumb = os.stat(os.path.join(self._dest_path, file_thumb))
 
+                for idx_ann, ann in enumerate(annotations[idx]["instances"]):
+                    if "bbox" in ann:
+                        annotations[idx]["instances"][idx_ann]["bbox"]["x_min"] *= scale
+                        annotations[idx]["instances"][idx_ann]["bbox"]["y_min"] *= scale
+                        annotations[idx]["instances"][idx_ann]["bbox"]["x_max"] *= scale
+                        annotations[idx]["instances"][idx_ann]["bbox"]["y_max"] *= scale
+
                 img_data = {
                     "_id": obj_id,
                     "date": pytz.utc.localize(datetime.datetime.now()),
